==> haskell-tasty-checklist-1.0.6.0-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.6.0
visibility:           public
id:                   tasty-checklist-1.0.6.0-LAFYJPUWYku2NPtVrpADSg
key:                  tasty-checklist-1.0.6.0-LAFYJPUWYku2NPtVrpADSg
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  3f4e9116939b9f96a39aaebff45ca8cf
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.6.0-LAFYJPUWYku2NPtVrpADSg
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5
    parameterized-utils-2.1.10.0-I5V20FAkpsg4emANlL3VZe text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-checklist-1.0.6.0-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-checklist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-checklist
version:              1.0.6.0
visibility:           public
id:                   tasty-checklist-1.0.6.0-EHGC9dp9r56GJ42gstSFHd
key:                  tasty-checklist-1.0.6.0-EHGC9dp9r56GJ42gstSFHd
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Check multiple items during a tasty test
description:
    Allows the test to check a number of items during a test and
    only signal pass or fail when the end if the checklist is reached.

    Also provides an easy method to check multiple derived values from
    a single input value.

category:             Testing
abi:                  abc47efee2eb97d55ba100c1dcacd7b6
exposed:              True
exposed-modules:      Test.Tasty.Checklist
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-checklist-1.0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-checklist
hs-libraries:         HStasty-checklist-1.0.6.0-EHGC9dp9r56GJ42gstSFHd
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5
    parameterized-utils-2.1.10.0-KqVWJwxXCFg3b4OEOOoxNm text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-checklist/html/tasty-checklist.haddock

haddock-html:         /usr/share/doc/haskell-tasty-checklist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
